@@ -1,7 +1,9 @@
+from openapi_core.contrib.flask.decorators import FlaskOpenAPIViewDecorator
 from openapi_core.contrib.flask.requests import FlaskOpenAPIRequest
 from openapi_core.contrib.flask.responses import FlaskOpenAPIResponse
 
 __all__ = [
+    "FlaskOpenAPIViewDecorator",
     "FlaskOpenAPIRequest",
     "FlaskOpenAPIResponse",
 ]
