@@ -1,4 +1,5 @@
 """OpenAPI core contrib werkzeug requests module"""
+
 import re
 from typing import Optional
 
@@ -6,17 +7,18 @@ from werkzeug.datastructures import Headers
 from werkzeug.datastructures import ImmutableMultiDict
 from werkzeug.wrappers import Request
 
-from openapi_core.validation.request.datatypes import RequestParameters
+from openapi_core.datatypes import RequestParameters
 
 # http://flask.pocoo.org/docs/1.0/quickstart/#variable-rules
 PATH_PARAMETER_PATTERN = r"<(?:(?:string|int|float|path|uuid):)?(\w+)>"
 
 
 class WerkzeugOpenAPIRequest:
-
     path_regex = re.compile(PATH_PARAMETER_PATTERN)
 
     def __init__(self, request: Request):
+        if not isinstance(request, Request):
+            raise TypeError(f"'request' argument is not type of {Request}")
         self.request = request
 
         self.parameters = RequestParameters(
@@ -38,12 +40,13 @@ class WerkzeugOpenAPIRequest:
         return self.request.method.lower()
 
     @property
-    def body(self) -> Optional[str]:
-        return self.request.get_data(as_text=True)
+    def body(self) -> Optional[bytes]:
+        return self.request.get_data(as_text=False)
 
     @property
-    def mimetype(self) -> str:
-        return self.request.mimetype
+    def content_type(self) -> str:
+        # default value according to RFC 2616
+        return self.request.content_type or "application/octet-stream"
 
     def get_path(self, path: str) -> str:
         return "".join([self.request.root_path, path])
